[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pype32: Yet another Python library to work with PE32 and PE64 file formats.
  - pype32.baseclasses: Base classes.
  - pype32.consts: Common definitions.
  - pype32.datadirs: Data directory classes.
  - pype32.datatypes: Data types objects.
  - pype32.directories: PE directory classes.
  - pype32.excep: Exceptions used by the entire library.
  - pype32.pype32: Common PE structures.
  - pype32.utils: Auxiliary classes and functions.